#
# spec file for package WoeUSB
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           WoeUSB
Version:        3.2.12
Release:        1.2
Summary:        Windows USB installation media creator
License:        GPL-3.0-or-later
Group:          System/Management
Url:            https://github.com/slacka/WoeUSB
Source:         https://github.com/slacka/WoeUSB/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  libtool
BuildRequires:  update-desktop-files
BuildRequires:  wxGTK3-devel

%description
WoeUSB is a utility for creating a bootable Windows installation
USB storage device from an existing Windows installation disc or disk image.

%prep
%setup -q
%autosetup

%build
find . -type f -exec sed -i "s/@@WOEUSB_VERSION@@/%{version}/" {} \+
autoreconf -fiv
%configure
make %{?_smp_mflags}

%install
%make_install
sed -i '1!b;s@/usr/bin/env bash@/bin/bash@' %{buildroot}%{_bindir}/woeusb %{buildroot}%{_datadir}/woeusb/data/listDvdDrive %{buildroot}%{_datadir}/woeusb/data/listUsb
rm %{buildroot}%{_datadir}/applications/woeusbgui.desktop
cp src/linux-menu/woeusbgui.desktop .
%suse_update_desktop_file -i -G "WoeUSB" -r woeusbgui System HardwareSettings
%fdupes %buildroot%{_datadir}

%files
%doc ChangeLog README.md README.upstream
%license COPYING
%{_bindir}/woeusb
%{_mandir}/man1/woeusb.1%{?ext_man}
%{_mandir}/man1/woeusbgui.1%{?ext_man}
%{_bindir}/woeusbgui
%{_datadir}/applications/woeusbgui.desktop
%{_datadir}/pixmaps/woeusbgui-icon.png
%dir %{_datadir}/woeusb
%dir %{_datadir}/woeusb/data
%{_datadir}/woeusb/data/c501-logo.png
%{_datadir}/woeusb/data/icon.png
%{_datadir}/woeusb/data/listDvdDrive
%{_datadir}/woeusb/data/listUsb
%{_datadir}/woeusb/data/woeusb-logo.png
%dir %{_datadir}/woeusb/locale
%dir %{_datadir}/woeusb/locale/fr
%dir %{_datadir}/woeusb/locale/fr/LC_MESSAGES
%dir %{_datadir}/woeusb/locale/zh_TW
%dir %{_datadir}/woeusb/locale/zh_TW/LC_MESSAGES
%lang(fr) %{_datadir}/woeusb/locale/fr/LC_MESSAGES/woeusb.mo
%lang(fr) %{_datadir}/woeusb/locale/fr/LC_MESSAGES/wxstd.mo
%lang(zh) %{_datadir}/woeusb/locale/zh_TW/LC_MESSAGES/woeusb.mo

%changelog
* Tue Dec 25 2018 Yunhe Guo <i@guoyunhe.me>
- Version 3.2.12
  * This release features some minor improvements to the code.
- Version 3.2.11
  * This release fixes a big regression causing source image with
    >4GiB file can't be installed on disks with NTFS target filesystem
    using --partition USB preparation mode, refer Issue #226 for more
    info.
  * We would like to thank Luke Anderson(@spble) that brought up the
    issue, @0xC1A551C for confirming it and providing mitigation,
    and everyone in the discussion thread that helped to escalate
    the issue.
* Wed Sep 19 2018 Yunhe Guo <yunhe.guo@protonmail.com>
- Version 3.2.10
  * This release fixes a regression that makes the --partition
    device preparation mode failed to work. We would like to thank
    @jackvnimble for the patch!
* Sun Sep 16 2018 Yunhe Guo <yunhe.guo@protonmail.com>
- Version 3.2.9
  * This release fixes a regression that will make --target-filesystem
    command-line option not working(#210).  We would like to thank
    @mishka81 for bringing up the issue.
- Version 3.2.8
  * This release fixes a typecasting bug in the graphical wrapper
    code. We would like to thank @dcb314 and @Skrilltrax for bringing
    it up and provide the patch!
- Version 3.2.7
  * This release fixes a typo which will lead to command not found
    when FAT32 4GiB single file size limitation is detected. Enjoy!
- Version 3.2.6
  * This release fixes a issue when user uses lowercase filesystem
    name as --target-filesystem's argument.
- Version 3.2.5
  * This release fixes a major regression introduced by v3.2.4.
* Thu Sep 13 2018 Yunhe Guo <yunhe.guo@protonmail.com>
- Version 3.2.4
  * This release features a major cleanup to the code, be sure to
    report any regressions you've encountered.
- Version 3.2.3
  * This release fixes a bug that will make woeusb bailout when the
    ISO filename contains a valid token of a regular expression.
* Tue Aug 14 2018 guoyunhebrave@gmail.com
- Version 3.2.2
  * This release improves compatibility with space-included filenames.
* Wed May  9 2018 guoyunhebrave@gmail.com
- Version 3.2.1
  * This patch release fixes the fatal error slipped into last minute patch in v3.2.0.
* Tue May  8 2018 guoyunhebrave@gmail.com
- Version 3.2.0
  * A check for "FAT32 Filesystem 4GiB Single File Size Limitation" has been
    implemented thanks to Jakub Szymański
  * A fix to comply with the recent changes of UEFI:NTFS has been implemented
    thanks to Felipe Magno de Almeida
  * PNG images distributed in WoeUSB has been optimized to smaller size thanks
    to Peter Dave Hello
  * A typo has been picked out in woeusb(1) manpage thanks to Anthony Fok
  * Detailed changes see https://github.com/slacka/WoeUSB/releases/tag/v3.2.0
* Thu Mar 29 2018 guoyunhebrave@gmail.com
- Version 3.1.5
  * Packaging: Debian: Downgrade debian/compat to 9 to match debian/control
  * Packaging: Debian: Downgrade debhelper dependency to v9 to support Ubuntu 14.04(till April 2019)
  * Packaging: Debian: Add missing build dependency: dh-autoreconf
  * Packaging: Debian: Depend on grub2-common instead of grub-common
  * Packaging: Debian: Add gettext package as build dependencies
  * Merge branch 'master' of github.com:slacka/WoeUSB
  * Manpages: woeusbgui(1): Fix typo
  * Add VCS- fields to debian/control
  * Remove versioned dependencies where satisfied by all releases since oldoldstable (Wheezy)
  * Remove dependencies on essential packages as they're always there
  * Fix priority-extra-is-replaced-by-priority-optional
  * Bump Debian Standards Version to 4.1.1
  * build-depends-on-1-revision build-depends: coreutils (>= 8.23-1)
  * Remove trailing whitespace
  * Fix obsolete-relation-form-in-source in woeusb depends: bash (>4.3)
  * core: Eliminate abused double quotes
* Sat Mar 10 2018 sebix+novell.com@sebix.at
- update to version 3.1.4:
  * no changelog available, please see https://github.com/slacka/WoeUSB/commits/master
* Mon Jan 15 2018 jengelh@inai.de
- Avoid assuming specific user context in description.
* Fri Dec 22 2017 sebix+novell.com@sebix.at
- inital package for version 2.2.2
